/**
 * Created by mircea on 22/03/2017.
 */

// Initialize ion Sound
ion.sound({
    sounds: [
        {name: 'error'}
    ],
    path: ive.ion_assets_path,
    preload: true
});

var editor_wrap = jQuery('#wp-content-wrap');

var tabs_container = editor_wrap.find('.wp-editor-tabs');

// append button as soon as possible because the script is loaded in the footer
tabs_container.append('<button type="button" id="ive_button" class="switch-ive wp-switch-editor" @click.prevent.stop="show">Flow</button>');

/*
 Help component
 */
Vue.component('help', {
    template: '#help-template',
    data: function () {
        return {
            content: {
                title: 'Want help? It\'s easy. Simply keep typing and when you\'re finished, type the ESC key. :)',
                ok: 'OK'
            }
        }
    },
    methods: {
        close: function () {
            this.$emit('close');
        }
    }
});

/*
 Flow component
 */
Vue.component('flow', {
    template: '#flow-template',
    mounted: function () {
        document.addEventListener('keydown', this.handleKeyDown);
        document.addEventListener('keyup', this.handleKeyUp);
        document.addEventListener('mousemove', this.handleMouseMove);
        document.addEventListener('click', this.focusInput);

        this.$parent.text = jQuery('#content').val();

        // Focus input
        this.$refs.inputText.focus();
    },
    beforeDestroy: function() {
        document.removeEventListener('keydown', this.handleKeyDown);
        document.removeEventListener('keyup', this.handleKeyUp);
        document.removeEventListener('mousemove', this.handleMouseMove);
        document.removeEventListener('click', this.focusInput);
    },
    data: function () {
        return {
            currentKey: '',
            currentWord: '',
            keyError: false,
            isWriting: false,
            ninjaMode: false,
            ninjaModeNotification: false,
            showHelp: false,
            content: {
                ninjaMode: 'Ninja Mode'
            }
        }
    },
    methods: {
        handleKeyDown: function (event) {
            const code = event.which || event.keyCode;
            if (!this.showHelp) {
                const isSpace = code === 32;
                const isEnter = code === 13;
                const key = isEnter ? '\n' : event.key;
                if (isEnter || key.length === 1) { // Check if the key is Enter or a single-char key
                    this.currentKey = isEnter ? '' : key;
                    if (isEnter || isSpace) {
                        this.currentWord = '';
                    } else {
                        this.currentWord = this.currentWord + key;
                    }
                    this.$parent.text += key;
                    this.isWriting = true;
                    this.ninjaModeNotification = false;
                    if ( isEnter ) {
                        event.preventDefault();
                    }
                } else if (code === 46 || code === 8) { // Check for delete or backspace
                    this.keyError = true;
                    if (!this.ninjaMode) {
                        ion.sound.play('error');
                    }
                } else if (code === 9) { // Check for tab
                    this.focusInput();
                } else if (code === 27) { // Check for Esc
                    this.close();
                }
            } else if (code === 27) { // Check for Esc
                this.showHelp = false;
            }
        },
        handleKeyUp: function () {
            if (this.keyError) {
                this.keyError = false;
            }
        },
        handleMouseMove: function () {
            this.isWriting = false;
        },
        focusInput: function () {
            var input = this.$refs.inputText;
            setTimeout(function () {
                if (input) {
                    input.focus();
                }
            });
        },
        toggleNinjaMode: function () {
            this.ninjaMode = !this.ninjaMode;
            this.ninjaModeNotification = true;
        },
        close: function () {
            if (tinyMCE && tinyMCE.activeEditor) {

                tinyMCE.activeEditor.setContent(this.$parent.text.replace(/\r?\n/g, '<br />'));
            }
            jQuery('#content').val(this.$parent.text);
            this.$emit('close');
        }
    }
});

new Vue({
    el: '#post-body-content',
    data: {
        showFlow: false,
        text: ''
    },
    methods: {
        show : function () {
            this.showFlow = true;
            this.triggerTracking();
        },
        triggerTracking : function() {
            if ( ive.tracking ) {
                console.log('triggered');
                jQuery('#ive_tracking_frame').remove();
                jQuery('body').append('<div class="ive_tracking" id="ive_tracking_frame"><iframe src="'+ive.tracking_url+'"></iframe> </div>')
            }
        }
    }
});
