<?php

// prevent accessing this file directly
if (!defined('ABSPATH')) {
    exit;
}

class ive_editor
{

    public static $allowed_pages = array(
        'post-new.php',
        'post.php'
    );

    public function __construct()
    {

        // hide default message
        add_filter('ive_default_textarea_message', '__return_false');

        add_action('admin_enqueue_scripts', array($this, 'scripts'));

        add_action('edit_form_after_editor', array($this, 'overlay_markup'));

        add_action('admin_head', array($this, 'overlay_template'));

    }

    public function scripts($page)
    {

        if (in_array($page, self::$allowed_pages)) {

            wp_register_style('ive_cutive_font', 'https://fonts.googleapis.com/css?family=Cutive+Mono');
            wp_enqueue_style('ive_main_css', plugin_dir_url(IVE_PLUGIN_FILE) . 'assets/css/ive.css', array('ive_cutive_font'), '1.0.0');

            wp_register_script('ive_vue_js', plugin_dir_url(IVE_PLUGIN_FILE) . 'assets/js/vue.min.js', array(), '2.2.4', true);
            wp_register_script('ive_ion_sound', plugin_dir_url(IVE_PLUGIN_FILE) . 'assets/js/ion.sound.min.js', array(), '3.0.7', true);
            wp_register_script('ive_main_js', plugin_dir_url(IVE_PLUGIN_FILE) . 'assets/js/ive_main.js', array('jquery', 'ive_vue_js', 'ive_ion_sound'), '1.0.0', true);

            // add string localization if needed
            global $ive_admin;
            wp_localize_script('ive_main_js', 'ive', array(
                'default_message' => apply_filters('ive_default_textarea_message', __('This is a great place to write', 'ive')),
                'ion_assets_path' => plugin_dir_url(IVE_PLUGIN_FILE) . 'assets/sounds/',
                'tracking' => isset($ive_admin->tracking['allow']) ? $ive_admin->tracking['allow'] : false,
                'tracking_url' => 'https://www.ilys.com/flow-ga.html'
            ));

            wp_enqueue_script('ive_main_js');

        }

    }

    public function overlay_markup()
    {

        include_once plugin_dir_path(IVE_PLUGIN_FILE) . 'templates/modal_template.php';

    }

    public function overlay_template()
    {

        ?>
        <!-- template for the modal component -->
        <script type="text/x-template" id="help-template">
            <transition name="modal">
                <div class="help-component">
                    <div class="help-overlay" @click.prevent.stop="close"></div>
                    <div class="help-modal">
                        <h3 class="help-modal-title">{{ content.title }}</h3>
                        <button class="help-modal-button" @click.prevent.stop="close">{{ content.ok }}</button>
                    </div>
                </div>
            </transition>
        </script>
        <script type="text/x-template" id="flow-template">
            <transition name="modal">
                <div class="write-component" :class="{ writing: isWriting, 'ninja-mode': ninjaMode }">
                    <div v-if="ninjaModeNotification" class="words-count-label deep-">
                        {{ content.ninjaMode }} {{ ninjaMode ? 'On' : 'Off' }}
                    </div>
                    <div class="write-nav">
                        <a class="help-icon ive_tooltip" @click.prevent.stop="showHelp = true" data-content="Help">
                            <span class="dashicons dashicons-editor-help"></span>
                        </a>
                    </div>
                    <a @click="toggleNinjaMode" class="ninja-toggle ive_tooltip" data-content="<?php _e('Ninja Mode!', 'ive'); ?>">
                        <label class="switch" v-bind:class="{ active: ninjaMode }">
                            <div class="slider"></div>
                        </label>
                    </a>
                    <div class="ilys-more">
                        <span><?php _e('Love Flow and', 'ive'); ?></span>
                        <a href="https://www.ilys.com/?ref=wpflowbasic" target="_blank"><?php _e('want more'); ?></a><span>?</span>
                    </div>
                    <div v-if="keyError" class="key-error">
                        <span class="dashicons dashicons-no"></span>
                    </div>
                    <div v-show="!ninjaMode" class="current-key" :class="{ 'current-key-error': keyError }">{{ currentKey }}</div>
                    <input @blur="focusInput" :value="currentWord" class="flow-entry-input" type="text" maxlength="1"
                           ref="inputText" autofocus>
                    <help v-if="showHelp" @close="showHelp = false"></help>
                </div>
            </transition>
        </script>
        <?php

    }

}

new ive_editor();